﻿<?xml version="1.0" encoding="utf-8"?>
<pattern id="Content" xmlns="http://purl.oclc.org/dsdl/schematron" xmlns:function="http://ato.gov.au/SWSFunctions">
  <title>Content Validations</title>

  <rule context="xbrli:xbrl[not(@i:nil='true')]">

    <!-- Rule ID: VR.ATO.IITR.000071
      ELS Ref: V100
    
      IF ([iitr172] + [iitr174]) > (RP:period.endDate - RP:period.startDate+1)
           RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr172] = rvctc2.xx.xx:IncomeTax.MedicareLevy.ExemptionFullDays.Count
      [iitr174] = rvctc2.xx.xx:IncomeTax.MedicareLevy.ExemptionHalfDays.Count
    -->
    <let name="startDate" value="xbrli:context[@id = $IITR.RP.ContextId][1]/xbrli:period/xbrli:startDate" />
    <let name="endDate"   value="xbrli:context[@id = $IITR.RP.ContextId][1]/xbrli:period/xbrli:endDate" />

    <assert  id="VR.ATO.IITR.000071" diagnostics="DVR.ATO.IITR.000071"
             test="not(
                          $startDate[not(@i:nil='true')] 
                          and 
                          $endDate[not(@i:nil='true')]
                          and
                          (
                              sum($iitr172|$iitr174) 
                              > 
                              function:DaysFromDate1ToDate2
                              (
                                  xs:date($endDate),
                                  xs:date($startDate)
                              ) + 1
                          )
                      )"/>
    

    <!-- Rule ID: VR.ATO.IITR.000501
      ELS Ref: V372
    
      IF ([iitr173] <> NULL) AND (([iitr172] = NULL) OR ([iitr172] = 0))
        RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr172] = rvctc2.xx.xx:IncomeTax.MedicareLevy.ExemptionFullDays.Count
      [iitr173] = rvctc2.xx.xx:IncomeTax.MedicareLevy.ExemptionFullDays.Code
    -->
    <assert  id="VR.ATO.IITR.000501" diagnostics="DVR.ATO.IITR.000501"
             test="not(
                          $iitr173[not(@i:nil='true')]
                          and
                          (
                            not($iitr172[not(@i:nil='true')])
                            or
                            $iitr172[. = 0]
                          )
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.000502
      ELS Ref: V117E
    
      IF ([iitr176] <> TRUE AND [iitr177] = NULLORBLANK)
        RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr176] = rvctc2.xx.xx:IncomeTax.MedicareLevy.PrivateHospitalCoverWholePeriod.Indicator
      [iitr177] = rvctc2.xx.xx:IncomeTax.MedicareLevy.SurchargeExemptionDays.Count
    -->
    <assert  id="VR.ATO.IITR.000502" diagnostics="DVR.ATO.IITR.000502"
             test="not(
                          $iitr176[not(matches(.,'^(true|1)$'))]
                          and
                          not($iitr177[not(@i:nil='true') and string-length(.) != 0])
                      )"/>

    
    <!-- Rule ID: VR.ATO.IITR.000504
      ELS Ref: V117G
      
      IF [iitr176] = TRUE AND ([iitr177] <> NULL AND [iitr177] <> (RP:Period.endDate - RP:Period.startDate+1))
           RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr176] = rvctc2.xx.xx:IncomeTax.MedicareLevy.PrivateHospitalCoverWholePeriod.Indicator
      [iitr177] = rvctc2.xx.xx:IncomeTax.MedicareLevy.SurchargeExemptionDays.Count
    -->
    <assert  id="VR.ATO.IITR.000504" diagnostics="DVR.ATO.IITR.000504"
             test="not(
                          $startDate[not(@i:nil='true')] 
                          and 
                          $endDate[not(@i:nil='true')]
                          and
                          $iitr176[matches(.,'^(true|1)$')]
                          and
                          $iitr177[not(@i:nil='true')] 
                          and
                          (
                              $iitr177 
                              != 
                              function:DaysFromDate1ToDate2
                              (
                                  xs:date($endDate),
                                  xs:date($startDate)
                              ) + 1
                          )
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.000505
      ELS Ref: V2781
      
      IF [iitr177]> (RP:period.endDate - RP:period.startDate +1)
           RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr177] = rvctc2.xx.xx:IncomeTax.MedicareLevy.SurchargeExemptionDays.Count
    -->
    <assert  id="VR.ATO.IITR.000505" diagnostics="DVR.ATO.IITR.000505"
             test="not(
                          $startDate[not(@i:nil='true')] 
                          and 
                          $endDate[not(@i:nil='true')]
                          and
                          (
                              $iitr177 
                              >
                              function:DaysFromDate1ToDate2
                              (
                                  xs:date($endDate),
                                  xs:date($startDate)
                              ) + 1
                          )
                      )"/>
    

    <!-- Rule ID: VR.ATO.IITR.000506
      ELS Ref: V1901
    
      IF [iitr163] = NULLORBLANK AND [iitr164] <> NULLORBLANK
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr163] = gfati.xx.xx:TaxOffsetClaim.SeniorAndPensioner.Code
    -->
    <assert  id="VR.ATO.IITR.000506" diagnostics="DVR.ATO.IITR.000506"
             test="not(
                          not($iitr163[not(@i:nil='true') and string-length(.) != 0])
                          and
                          $iitr164[not(@i:nil='true') and string-length(.) != 0]
                      )"/>
    

    <!-- Rule ID: VR.ATO.IITR.000507
      ELS Ref: V99
    
      IF (
             ([iitr168] = NULL) 
             AND 
             (
                ( [iitr166] + [iitr379]  + [iitr381] + [iitr386] + [iitr388] + [iitr392] + [iitr395] <> 0)
             ) 
         )
         OR 
         (
            ([iitr168] <> NULL) 
            AND 
            (
                [iitr168] <> ([iitr166] + [iitr379]  + [iitr381] + [iitr386] + [iitr388] + [iitr392] + [iitr395])
            )
         )
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr168] = gfati.xx.xx:TaxOffsetClaim.Total.Amount
      [iitr166] = gfati.xx.xx:gfati.02.00:TaxOffsetClaim.SuperannuationIncomeStream.Amount
      [iitr379] = gfati.xx.xx:TaxOffsetClaim.SuperannuationContributionSpouse.Amount
      [iitr381] = gfati.xx.xx:TaxOffsetClaim.ZoneOrOverseasForces.Amount
      [iitr386] = gfati.xx.xx:TaxOffsetClaim.DependentInvalidAndCarer.Amount
      [iitr388] = gfati.xx.xx:TaxOffsetClaim.LandcareAndWaterFacilityBroughtForward.Amount
      [iitr392] = gfati.xx.xx:TaxOffsetClaim.NonRefundableOther.Amount
      [iitr395] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Amount
    -->
    <assert  id="VR.ATO.IITR.000507" diagnostics="DVR.ATO.IITR.000507"
             test="not(
                          sum($iitr168) != sum( $iitr166 | $iitr379 | $iitr381 | $iitr386 | $iitr388 | $iitr392 | $iitr395)
                      )"/>
    
    
   
    <!-- Rule ID: VR.ATO.IITR.000601
      ELS Ref: V117J
    
      IF (([iitr180] <> NULLORBLANK)) AND (([iitr180] = "OTH")) AND (([iitr31] = NULLORBLANK)) 
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
      [iitr31] = bafot.xx.xx:RegulatoryDisclosures.GeneralInformationAboutFinancialStatements.Text
    -->
    <assert  id="VR.ATO.IITR.000601" diagnostics="DVR.ATO.IITR.000601"
             test="not(
                          $iitr180[not(@i:nil='true') and string-length(.) != 0]
                          and
                          $iitr180 = 'OTH' 
                          and
                          not($iitr31[not(@i:nil='true') and string-length(.) != 0])
                      )"/>

    
    <!-- Rule ID: VR.ATO.IITR.000602
      ELS Ref: V334
    
      IF ([iitr180] <> NULLORBLANK) AND ([iitr180] <> SET(DOMAIN(HEALTH INSURER ID CODES)))
         RETURN VALIDATION MESSAGE
      ENDIF

      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
    -->
    <assert id="VR.ATO.IITR.000602" diagnostics="DVR.ATO.IITR.000602"
            test="not(    
                          $iitr180[
                            upper-case(.) != 'ACA' and
                            upper-case(.) != 'AHB' and
                            upper-case(.) != 'AHM' and
                            upper-case(.) != 'AMA' and
                            upper-case(.) != 'AUF' and
                            upper-case(.) != 'BUP' and
                            upper-case(.) != 'CBH' and
                            upper-case(.) != 'CDH' and
                            upper-case(.) != 'CPS' and
                            upper-case(.) != 'FAI' and
                            upper-case(.) != 'GMH' and
                            upper-case(.) != 'HBF' and
                            upper-case(.) != 'HCF' and
                            upper-case(.) != 'HCI' and
                            upper-case(.) != 'HEA' and
                            upper-case(.) != 'HHB' and
                            upper-case(.) != 'HIF' and
                            upper-case(.) != 'LHM' and
                            upper-case(.) != 'LHS' and
                            upper-case(.) != 'MBP' and
                            upper-case(.) != 'MDH' and
                            upper-case(.) != 'NHB' and
                            upper-case(.) != 'NIB' and
                            upper-case(.) != 'NTF' and
                            upper-case(.) != 'OMF' and
                            upper-case(.) != 'OTH' and
                            upper-case(.) != 'PWA' and
                            upper-case(.) != 'QCH' and
                            upper-case(.) != 'QTU' and
                            upper-case(.) != 'RBH' and
                            upper-case(.) != 'RTE' and
                            upper-case(.) != 'SLM' and
                            upper-case(.) != 'SPE' and
                            upper-case(.) != 'SPS' and
                            upper-case(.) != 'TFS' and
                            upper-case(.) != 'WFD'
                          ]
                       ) "/>


    <!-- Rule ID: VR.ATO.IITR.000608
      ELS Ref: V183A
    
      IF ([iitr378] <> NULL) AND ([iitr378] > 0) AND (([iitr379] = NULL) OR ([iitr379] = 0))
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr378] = emsup.xx.xx:SuperannuationContribution.SpouseContributions.Amount
      [iitr379] = gfati.xx.xx:TaxOffsetClaim.SuperannuationContributionSpouse.Amount
    -->
    <assert  id="VR.ATO.IITR.000608" diagnostics="DVR.ATO.IITR.000608"
             test="not(
                          $iitr378[not(@i:nil='true') and string-length(.) != 0 and . > 0]
                          and
                          (
                            not($iitr379[not(@i:nil='true') and string-length(.) != 0])
                            or
                            $iitr379[not(@i:nil='true') and string-length(.) != 0 and . = 0]
                          )
                      )"/>

    <!-- Rule ID: VR.ATO.IITR.000609
      ELS Ref: V183B
    
      IF ([iitr379] <> NULL) AND ([iitr379] > 0) AND (([iitr378] = NULL) OR ([iitr378] = 0))
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr378] = emsup.xx.xx:SuperannuationContribution.SpouseContributions.Amount
      [iitr379] = gfati.xx.xx:TaxOffsetClaim.SuperannuationContributionSpouse.Amount
    -->
    <assert  id="VR.ATO.IITR.000609" diagnostics="DVR.ATO.IITR.000609"
             test="not(
                          $iitr379[not(@i:nil='true') and string-length(.) != 0 and . > 0]
                          and
                          (
                            not($iitr378[not(@i:nil='true') and string-length(.) != 0])
                            or
                            $iitr378[not(@i:nil='true') and string-length(.) != 0 and . = 0]
                          )
                      )"/>


    
   <!-- Rule ID: VR.ATO.IITR.000612
      ELS Ref: V151
    
      IF ([iitr393] <> NULL) AND ([iitr392] = NULL OR [iitr392] = 0)
         RETURN VALIDATION MESSAGE
      ENDIF

      [iitr393] = gfati.xx.xx:TaxOffsetClaim.NonRefundableOther.Code
      [iitr392] = gfati.xx.xx:TaxOffsetClaim.NonRefundableOther.Amount
    -->
    <assert  id="VR.ATO.IITR.000612" diagnostics="DVR.ATO.IITR.000612"
             test="not(
                          $iitr393[not(@i:nil='true')]
                          and
                          (
                            not($iitr392[not(@i:nil='true')])
                            or
                            $iitr392[. = 0]
                          )
                      )"/>

    
    <!-- Rule ID: VR.ATO.IITR.000613
      ELS Ref: V2625
    
      IF ([iitr395] <> NULL) AND ([iitr395] > 0) AND ([iitr396] = NULL) 
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr395] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Amount
      [iitr396] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Code
    -->
    <assert  id="VR.ATO.IITR.000613" diagnostics="DVR.ATO.IITR.000613"
             test="not(
                        $iitr395
                          [
                            not(@i:nil='true') and
                            . > 0
                          ]
                        and
                        not($iitr396[not(@i:nil='true')])
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.000614
      ELS Ref: V2626
    
      IF ([iitr396] <> NULL) AND (([iitr395] = NULL)  OR ([iitr395] = 0))
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr395] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Amount
      [iitr396] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Code
    -->
    <assert  id="VR.ATO.IITR.000614" diagnostics="DVR.ATO.IITR.000614"
             test="not(
                        $iitr396[not(@i:nil='true')]
                        and
                        (
                          not($iitr395[not(@i:nil='true')])
                          or
                          sum($iitr395) = 0
                        )
                      )"/>

    
    <!-- Rule ID: VR.ATO.IITR.210031
      ELS Ref: N/A
    
      IF ([iitr383] <> NULL) AND ([iitr384] = NULL)
           RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr383] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Amount
      [iitr384] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Code
    -->
    <assert  id="VR.ATO.IITR.210031" diagnostics="DVR.ATO.IITR.210031"
             test="not(
                        $iitr383[not(@i:nil='true')]
                        and
                        not($iitr384[not(@i:nil='true')])
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.210032
      ELS Ref: N/A
    
      IF ([iitr384] = TRUE) AND ([iitr383] = NULL)
           RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr383] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Amount
      [iitr384] = rvctc1.xx.xx:IncomeTax.TaxOffsetRefundableOther.Code
    -->
    <assert  id="VR.ATO.IITR.210032" diagnostics="DVR.ATO.IITR.210032"
             test="not(
                        $iitr384[matches(.,'^(true|1)$')]
                        and
                        not($iitr383[not(@i:nil='true')])
                      )"/>
  </rule>

  <!-- LOOP THROUGH REPORTING PARTY PRIVATE HEALTH INSURANCE SEQUENCE CONTEXTS -->
  <rule context="xbrli:xbrl/xbrli:context[not(@i:nil='true' or @i:nil='1') and 
        count(./xbrli:entity/xbrli:segment/
        xbrldi:typedMember[matches(@dimension,'^PHISqNumDim\.\d{2}\.\d{2}:PrivateHealthInsuranceSequenceDimension$')]) = 1]">

    <let name="thisContext" value="@id" />

    <!-- Rule ID: VR.ATO.IITR.000503
      ELS Ref: V117F
    
      IF ([iitr176] = TRUE AND ANY OCCURANCE OF ([iitr181] = NULLORBLANK OR [iitr180] = NULLORBLANK or [iitr185] = NULL))
        RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr176] = rvctc2.xx.xx:IncomeTax.MedicareLevy.PrivateHospitalCoverWholePeriod.Indicator
      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
      [iitr181] = pyid.xx.xx:Identifiers.HealthInsuranceMembership.Identifier
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <assert  id="VR.ATO.IITR.000503" diagnostics="DVR.ATO.IITR.000503"
             test="not(
                          $iitr176
                          [
                            matches(.,'^(true|1)$')
                          ]
                          and
                          (
                            not($iitr180[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContext])
                            or
                            not($iitr181[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContext])
                            or
                            not($iitr185[not(@i:nil='true') and @contextRef = $thisContext])
                          )
                      )"/>
    

    <!-- Rule ID: VR.ATO.IITR.000600
      ELS Ref: V117I
    
      IF ([iitr185] <> NULL) AND 
      ([iitr185] = SET("No dependants","Dependants","Claiming your share of rebate","Claiming your spouses share of rebate")) AND 
      ([iitr181] = NULLORBLANK OR 
      [iitr180] = NULL OR 
      [iitr182] = NULL OR 
      [iitr183] = NULL OR 
      [iitr184] = NULL)
         RETURN VALIDATION MESSAGE
      ENDIF

      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
      [iitr181] = pyid.xx.xx:Identifiers.HealthInsuranceMembership.Identifier
      [iitr182] = rvctc2.xx.xx:IncomeTax.HealthInsurance.RebatableComponent.Amount
      [iitr183] = rvctc2.xx.xx:IncomeTax.HealthInsurance.GovernmentRebateReceived.Amount
      [iitr184] = rvctc2.xx.xx:IncomeTax.HealthInsurance.Benefit.Code
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <assert  id="VR.ATO.IITR.000600" diagnostics="DVR.ATO.IITR.000600"
             test="not(
                          $iitr185
                          [
                            not(@i:nil='true') and string-length(.) != 0 and
                            @contextRef = $thisContext and
                            matches(.,'^(No dependants|Dependants|Claiming your share of rebate|Claiming your spouses share of rebate)$')
                          ]
                          and
                          (
                            not($iitr180[not(@i:nil='true') and @contextRef = $thisContext])
                            or
                            not($iitr181[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContext])
                            or
                            not($iitr182[not(@i:nil='true') and @contextRef = $thisContext])
                            or
                            not($iitr183[not(@i:nil='true') and @contextRef = $thisContext])
                            or
                            not($iitr184[not(@i:nil='true') and @contextRef = $thisContext])
                          )
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.000603
      ELS Ref: V2686
    
      IF (([iitr185] <> NULLORBLANK)) AND 
      (([iitr185] = SET("Spouse claiming your share of rebate","Covered as dependent child")) AND 
      ([iitr180] = NULLORBLANK) AND 
      ([iitr181] = NULLORBLANK))
         RETURN VALIDATION MESSAGE
      ENDIF

      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
      [iitr181] = pyid.xx.xx:Identifiers.HealthInsuranceMembership.Identifier
      [iitr182] = rvctc2.xx.xx:IncomeTax.HealthInsurance.RebatableComponent.Amount
      [iitr183] = rvctc2.xx.xx:IncomeTax.HealthInsurance.GovernmentRebateReceived.Amount
      [iitr184] = rvctc2.xx.xx:IncomeTax.HealthInsurance.Benefit.Code
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <assert  id="VR.ATO.IITR.000603" diagnostics="DVR.ATO.IITR.000603"
             test="not(
                          $iitr185
                          [
                            not(@i:nil='true') and string-length(.) != 0 and
                            @contextRef = $thisContext and
                            matches(.,'^(Spouse claiming your share of rebate|Covered as dependent child)$')
                          ]
                          and
                          not($iitr180[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContext])
                          and
                          not($iitr181[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContext])
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.000604
      ELS Ref: V2694
    
      IF ([iitr185:Claiming your spouses share of rebate] <> NULL) 
        AND 
        (
          (RP.{PHISeqNum} WHERE 
            (
              [iitr185] = "Claiming your share of rebate" 
              AND 
              [iitr180: Claiming your spouses share of rebate] = [iitr180] 
              AND 
              [iitr181: Claiming your spouses share of rebate] = [iitr181]
            )
          ) = NULL
        )

      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
      [iitr181] = pyid.xx.xx:Identifiers.HealthInsuranceMembership.Identifier
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <let name="cContextRefs" value="$iitr185[. = 'Claiming your share of rebate']/@contextRef"/>
    
    <assert  id="VR.ATO.IITR.000604" diagnostics="DVR.ATO.IITR.000604"
             test="not(
                          not(
                            some $cContextRef in $cContextRefs
			                      satisfies
			                      (
				                      $iitr180[@contextRef = $thisContext] = $iitr180[@contextRef = $cContextRef]
				                      and
				                      $iitr181[@contextRef = $thisContext] = $iitr181[@contextRef = $cContextRef]
			                      )
                          )
			                    and
			                    $iitr185[@contextRef = $thisContext] = 'Claiming your spouses share of rebate' 
                      )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.000605
      ELS Ref: V2764
    
      IF ([iitr180] <> NULL OR 
      [iitr181] <> NULLORBLANK OR 
      [iitr182] <> NULL OR 
      [iitr183] <> NULL OR 
      [iitr184] <> NULL) AND 
      ([iitr185] = NULL)
         RETURN VALIDATION MESSAGE
      ENDIF
      
      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
      [iitr181] = pyid.xx.xx:Identifiers.HealthInsuranceMembership.Identifier
      [iitr182] = rvctc2.xx.xx:IncomeTax.HealthInsurance.RebatableComponent.Amount
      [iitr183] = rvctc2.xx.xx:IncomeTax.HealthInsurance.GovernmentRebateReceived.Amount
      [iitr184] = rvctc2.xx.xx:IncomeTax.HealthInsurance.Benefit.Code
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <assert  id="VR.ATO.IITR.000605" diagnostics="DVR.ATO.IITR.000605"
             test="not(
                          not($iitr185[not(@i:nil='true') and @contextRef = $thisContext])
                          and
                          (
                            $iitr180[not(@i:nil='true') and @contextRef = $thisContext]
                            or
                            $iitr181[not(@i:nil='true') and string-length(.) != 0 and @contextRef = $thisContext]
                            or
                            $iitr182[not(@i:nil='true') and @contextRef = $thisContext]
                            or
                            $iitr183[not(@i:nil='true') and @contextRef = $thisContext]
                            or
                            $iitr184[not(@i:nil='true') and @contextRef = $thisContext]
                          )
                      )"/>


    <!-- Rule ID: VR.ATO.IITR.000607
      ELS Ref: V2688
    
      IF  ANY OCCURRENCE OF ([iitr185]) = "Covered as dependent child" AND 
      ([iitr29] <= CONVERT_TO_DATE(1,7, [iitr10] - 26))
        RETURN VALIDATION MESSAGE
      ENDIF

      [iitr10] = pyin.xx.xx:Report.TargetFinancial.Year
      [iitr29] = pyde.xx.xx:PersonDemographicDetails.Birth.Date
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <let name="Over25" value="concat($iitr10[not(@i:nil='true') and string-length(.) != 0]-26,'-07-01')" />
    
    <assert  id="VR.ATO.IITR.000607" diagnostics="DVR.ATO.IITR.000607"
             test="not(
                          $iitr185
                          [
                            not(@i:nil='true') and string-length(.) != 0 and
                            @contextRef = $thisContext and
                            . = 'Covered as dependent child'
                          ]
                          and
                          $iitr29[function:IsDate1GreaterOrEqualToDate2($Over25, .)]
                      )"/>

    
    <!-- Rule ID: VR.ATO.IITR.210034
      ELS Ref: V2803
    
	    WHERE IN RP.{PHISeqNum}
      IF ([iitr180] = [iitr180:Other]) AND ([iitr181] = [iitr181:Other]) AND ([iitr185] <> SET("Claiming your spouses share of rebate","Covered as dependent child")) AND ([iitr185] <> [iitr185:Other])
         RETURN VALIDATION MESSAGE
      ENDIF

      [iitr180:Other] = ANY OTHER OCCURRENCE OF ([iitr180] WHERE  [iitr185] <> SET("Claiming your spouses share of rebate","Covered as dependent child"))
      [iitr181:Other] = ANY OTHER OCCURRENCE OF ([iitr181] WHERE  [iitr185] <> SET("Claiming your spouses share of rebate","Covered as dependent child"))
      [iitr185:Other] = ANY OTHER OCCURRENCE OF ([iitr185] WHERE  [iitr185] <> SET("Claiming your spouses share of rebate","Covered as dependent child"))
    
    
      [iitr180] = pyid.xx.xx:Identifiers.HealthInsuranceProvider.Identifier
      [iitr181] = pyid.xx.xx:Identifiers.HealthInsuranceMembership.Identifier
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <let name="ABCEContextRefs" value="$iitr185[. = 'No dependants' or . = 'Dependants' or . = 'Claiming your share of rebate' or . = 'Spouse claiming your share of rebate']/@contextRef"/>
    <let name="DFContextRefs" value="$iitr185[. = 'Claiming your spouses share of rebate' or . = 'Covered as dependent child']/@contextRef"/>
    
    <assert  id="VR.ATO.IITR.210034" diagnostics="DVR.ATO.IITR.210034"
             test="not(
                        $iitr185[@contextRef = $thisContext and (. = 'No dependants' or . = 'Dependants' or . = 'Claiming your share of rebate' or . = 'Spouse claiming your share of rebate')]
                        and
                        (
                          (
                            some $ABCEContextRef in $ABCEContextRefs
			                      satisfies
			                      (
                              $thisContext != $ABCEContextRef
                              and
				                      $iitr180[@contextRef = $thisContext] = $iitr180[@contextRef = $ABCEContextRef]
				                      and
				                      $iitr181[@contextRef = $thisContext] = $iitr181[@contextRef = $ABCEContextRef]
                              and
                              $iitr185[@contextRef = $thisContext] != $iitr185[@contextRef = $ABCEContextRef]
			                      )
                          )
                        ) 
                      )"/>
    
    
    <!-- Rule ID: VR.ATO.IITR.210035
      ELS Ref: V2804
    
      WHERE IN RP.{PHISeqNum}
      IF ([iitr185] = SET("No dependants", "Dependants", "Claiming your share of rebate", "Claiming your spouses share of rebate")) 
        AND ([iitr183] > 0) 
        AND 
        (
          (
            [iitr182] <> NULL 
            AND 
            [iitr183] >= [iitr182]
          ) 
          OR 
          ([iitr182] = NULL))
         RETURN VALIDATION MESSAGE
      ENDIF

      [iitr182] = rvctc2.xx.xx:IncomeTax.HealthInsurance.RebatableComponent.Amount
      [iitr183] = rvctc2.xx.xx:IncomeTax.HealthInsurance.GovernmentRebateReceived.Amount
      [iitr185] = rvctc2.xx.xx:IncomeTax.HealthInsurance.TaxClaim.Code
    -->
    <assert  id="VR.ATO.IITR.210035" diagnostics="DVR.ATO.IITR.210035"
             test="not(
                          $iitr185
                          [
                            @contextRef = $thisContext and
                            matches(.,'^(No dependants|Dependants|Claiming your share of rebate|Claiming your spouses share of rebate)$')
                          ]
                          and
                          sum($iitr183[@contextRef = $thisContext]) > 0
                          and
                          sum($iitr183[@contextRef = $thisContext]) >= sum($iitr182[@contextRef = $thisContext])
                      )"/>

  </rule>

</pattern>
